# vasp.recipes module

```{eval-rst}
.. automodule:: vasp.recipes
   :members:
   :undoc-members:
   :show-inheritance:
```

## Core Recipes

```{eval-rst}
.. automodule:: vasp.recipes.core
   :members:
   :undoc-members:
   :show-inheritance:
```

## Slab Recipes

```{eval-rst}
.. automodule:: vasp.recipes.slabs
   :members:
   :undoc-members:
   :show-inheritance:
```

## Phonon Recipes

```{eval-rst}
.. automodule:: vasp.recipes.phonons
   :members:
   :undoc-members:
   :show-inheritance:
```
